@@ -13,7 +13,7 @@ use std::time::Duration;
 
 use color_eyre::eyre::{Context, Result};
 use eyre::bail;
-use filetime::{set_file_times, FileTime};
+use filetime::{FileTime, set_file_times};
 use flate2::read::GzDecoder;
 use itertools::Itertools;
 use rayon::prelude::*;
@@ -553,11 +553,7 @@ fn _which<P: AsRef<Path>>(name: P, paths: &[PathBuf]) -> Option<PathBuf> {
     let name = name.as_ref();
     paths.par_iter().find_map_first(|path| {
         let bin = path.join(name);
-        if is_executable(&bin) {
-            Some(bin)
-        } else {
-            None
-        }
+        if is_executable(&bin) { Some(bin) } else { None }
     })
 }
 
