@@ -6,9 +6,9 @@ use std::{panic, thread};
 
 use crate::backend::Backend;
 use crate::cli::args::BackendArg;
-use crate::config::env_directive::{EnvResolveOptions, EnvResults};
-use crate::config::settings::{SettingsStatusMissingTools, SETTINGS};
 use crate::config::Config;
+use crate::config::env_directive::{EnvResolveOptions, EnvResults};
+use crate::config::settings::{SETTINGS, SettingsStatusMissingTools};
 use crate::env::{PATH_KEY, TERM_WIDTH};
 use crate::env_diff::EnvMap;
 use crate::errors::Error;
@@ -20,12 +20,12 @@ use crate::uv::UV_VENV;
 use crate::{backend, config, env, hooks};
 pub use builder::ToolsetBuilder;
 use console::truncate_str;
-use eyre::{eyre, Result, WrapErr};
+use eyre::{Result, WrapErr, eyre};
 use indexmap::{IndexMap, IndexSet};
 use itertools::Itertools;
 use once_cell::sync::OnceCell;
-pub use outdated_info::is_outdated_version;
 use outdated_info::OutdatedInfo;
+pub use outdated_info::is_outdated_version;
 use rayon::prelude::*;
 pub use tool_request::ToolRequest;
 pub use tool_request_set::{ToolRequestSet, ToolRequestSetBuilder};
